@@ -43,9 +43,9 @@ class SystemDesign(object):
     ac_capacity: float
     poi_limit: float
     gcr: float
-    modules_per_string: t.Optional[int]
-    strings_in_parallel: t.Optional[int]
     tracking: t.Union[FixedTilt, SingleAxisTracking]
+    modules_per_string: t.Optional[int] = opt_field()
+    strings_in_parallel: t.Optional[int] = opt_field()
     azimuth: t.Optional[float] = opt_field()
 
 @dataclass_json
